#common.Utility.py
"""
	Contains constants and functions for image loading.
"""

import pygame
import os
import math

from pygame.locals import *

version = "Mr. Frog vs. OSIRIS, LORD OF THE UNDERWORLD 1.0"

loadedImages = {}
fonts = {}

#load feldman sprites
feldman1 = pygame.image.load("data/images/blocks1.bmp")
feldman2 = pygame.image.load("data/images/blocks2.bmp")
feldman1.set_colorkey((0, 0, 0))
feldman2.set_colorkey((0, 0, 0))

def distance(x1, y1, x2, y2):
	"""
		Return the geometric distance between two points.
	"""
	return math.sqrt(math.pow((x1 - x2), 2) + math.pow((y1 - y2), 2))

def floatIsZero(f):
	"""
		Return if a float is equal to zero.
		Avoids nasty computer floating point errors.
	"""
	tolerance = 0.005
	if f + tolerance > 0.0 and f - tolerance < 0.0:
		return True
	else:
		return False

def getGameFont():
	"""
		Returns the game font.  If the game font has not been loaded before, loads it from disk.
		Otherwise, load it from memory.
		current game font == freesansbold.ttf, font size of 12
	"""
	if not fonts.has_key("freesansbold.ttf"):
		fonts["freesansbold.ttf"] = pygame.font.Font("freesansbold.ttf", 12)
	return fonts["freesansbold.ttf"]

def splitFeldman(key, x, y):
        """
                Return one block of the Feldman sprite sheet.
                key = which sheet, 0 or 1
                x, y = index into spritesheet
        """
        #31 pixels in length
        #31 pixels in height
        #2 pixel seperator
        actual_surf = pygame.Surface((32, 32), flags=SRCALPHA)
        if key == 0:
                actual_surf.blit(feldman1, (0, 0), area=(pygame.Rect(2 * (x + 1) + (32 * x), 2 * (y + 1) + (32 * y), 32, 32)))
        else:
                actual_surf.blit(feldman2, (0, 0), area=(pygame.Rect(2 * (x + 1) + (32 * x), 2 * (y + 1) + (32 * y), 32, 32)))
        #actual_surf.set_colorkey((0, 0, 0))
        return actual_surf


def smartLoadImage(fileName):
	"""
		Returns a pygame image from a filename.  If the image has not been loaded before, it loads it from disk.
		Otherwise, load it from memory.
	"""
	if not loadedImages.has_key(fileName):
		loadedImages[fileName] = load_image(fileName)
	return loadedImages[fileName]

def getImages(descrip):
	"""
	Given a string image description (not a filename), returns the list of images associated with it.
	This funciton is to be used with Netsprites.
	"""
	images = []
	if descrip == "frog":
                images.append(smartLoadImage("frogStandRight.png"))
                images.append(smartLoadImage("frogPrepareRight.png"))
                images.append(smartLoadImage("frogJumpRight.png"))
                images.append(smartLoadImage("frogFallRight.png"))
                images.append(smartLoadImage("frogStandLeft.png"))
                images.append(smartLoadImage("frogPrepareLeft.png"))
                images.append(smartLoadImage("frogJumpLeft.png"))
                images.append(smartLoadImage("frogFallLeft.png"))
        elif descrip == "snakeLeft":
                images.append(smartLoadImage("snakeLeft3.png"))
                images.append(smartLoadImage("snakeLeft2.png"))
                images.append(smartLoadImage("snakeLeft1.png"))
                images.append(smartLoadImage("snakeLeft4.png"))
                images.append(smartLoadImage("snakeLeft1.png"))
                images.append(smartLoadImage("snakeLeft2.png"))
        elif descrip == "snakeRight":
                images.append(smartLoadImage("snakeRight3.png"))
                images.append(smartLoadImage("snakeRight2.png"))
                images.append(smartLoadImage("snakeRight1.png"))
                images.append(smartLoadImage("snakeRight4.png"))
                images.append(smartLoadImage("snakeRight1.png"))
                images.append(smartLoadImage("snakeRight2.png"))
	return images
	
def load_image(name):
	"""
	Given a filename (not a path), finds the file in the data/images directory and loads and returns a pygame
	image object found at that file.
	If the specified file cannot be found, generate an error to close the program.
	Thanks to the Pyman example on www.pygame.org for how to do this.
	"""
	fullname = os.path.join('data', 'images')
	fullname = os.path.join(fullname, name)
	try:
		image = pygame.image.load(fullname)
	except pygame.error, message:
		print('Cannot load image: ' + fullname)
		raise SystemExit, message
	image = image.convert_alpha()
	return image
	
def load_sound(name):
	"""
		Given a filename (not a path), finds the path to the file.
	"""
	fullname = os.path.join('data', 'sound')
	fullname = os.path.join(fullname, name)
	return fullname
